@@ -8,8 +8,13 @@
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
-from PyQt4.QtMaemo5 import *
 
+try:
+    from PyQt4.QtMaemo5 import *
+    isMAEMO = True
+except:
+    isMAEMO = False
+    
 #import khweeteur
 import twitter
 import sys
@@ -25,7 +30,7 @@ from PIL import Image
 import re
 import urllib2
 
-__version__ = '0.0.26'
+__version__ = '0.0.27'
 
 def write_report(error):
     filename = os.path.join(CACHE_PATH,'crash_report')
@@ -88,10 +93,12 @@ class KhweeteurNotification(QObject):
         self.m_id = 0
         
     def warn(self,message):
-        self.iface.SystemNoteDialog(message,0,'Nothing')
+        if isMAEMO:
+            self.iface.SystemNoteDialog(message,0,'Nothing')
         
     def info(self,message):
-        self.iface.SystemNoteInfoprint('Khweeteur : '+message)
+        if isMAEMO:
+            self.iface.SystemNoteInfoprint('Khweeteur : '+message)
         
     def notify(self,title,message,category='im.received',icon='khweeteur',count=1):
         self.m_id = self.iface.Notify('Khweeteur',
@@ -187,17 +194,14 @@ class KhweeteurActionWorker(QThread):
 #                self.tb_text.setText('')
 #                self.tb_text_replyid = 0
 #                self.tb_text_replytext = ''
-        except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
-            import traceback
-            print traceback.print_exc()
-            print traceback.print_stack()
+        except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
             if type(e)==twitter.TwitterError:
 #                self.notifications.warn('Send tweet failed : '+(e.message))
                 self.emit(SIGNAL("warn(PyQt_PyObject)"),e.message)
                 print e.message
             else:
 #                self.notifications.warn('Send tweet failed : '+str(e))
-                self.emit(SIGNAL("warn(PyQt_PyObject)"),str(e))
+                self.emit(SIGNAL("warn(PyQt_PyObject)"),'A network error occur')
                 print e 
 
                           
@@ -241,7 +245,7 @@ class KhweeteurWorker(QThread):
                     #im.save(os.path.splitext(cache)[0]+'.png', 'PNG', transparency=transparency)
                     im.save(os.path.splitext(cache)[0]+'.png', 'PNG')
 #                    print os.path.splitext(cache)[0]+'.png'
-                except (StandardError,urllib2.HTTPError),e:
+                except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                     print 'DownloadProfileImage Error : ',e
         
     def refresh_search(self):
@@ -267,9 +271,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError),e:
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
             print 'Error during refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+            self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
         try:
             identica_last_id = None
@@ -285,9 +289,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError),e:
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
             print 'Error during refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+            self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
 
         if len(mlist)>0:
@@ -340,9 +344,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during twitter refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError),e:
-            print 'Error during twitter refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+            print 'Error during twitter refresh : ',e
+            self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
         try:
             identica_last_id = None
@@ -381,9 +385,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during identi.ca refresh: ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError),e:
-            print 'Error during identi.ca refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+            print 'Error during identi.ca refresh : ',e
+            self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
                 
 
         if len(mlist)>0:
@@ -440,6 +444,7 @@ class KhweetsModel(QAbstractListModel):
         return len(self._items)
 
     def refreshTimestamp(self):
+        self.now = time.time()
         for index,item in enumerate(self._items):
             try:
                 self._items[index] = (item[0],
@@ -499,6 +504,9 @@ class KhweetsModel(QAbstractListModel):
             QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
             self.serialize()
 
+    def destroyStatus(self,index):
+        self._items.pop(index.row())
+        QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
             
     def getNewAndReset(self):
         counter = self._new_counter
@@ -604,7 +612,7 @@ class KhweetsModel(QAbstractListModel):
     def wantsUpdate(self):
         QObject.emit(self, SIGNAL("layoutChanged()"))
 
-class CustomDelegate(QStyledItemDelegate):
+class DefaultCustomDelegate(QStyledItemDelegate):
     '''Delegate to do custom draw of the items'''
 
     def __init__(self, parent):
@@ -630,6 +638,8 @@ class CustomDelegate(QStyledItemDelegate):
         if self.fm == None:
             self.fm = QFontMetrics(option.font)
         height = self.fm.boundingRect(0,0,option.rect.width()-75,800, int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet).height()
+        if height<37:
+            height=37        
         return QSize(size.width(), height+25)
         
 
@@ -661,7 +671,7 @@ class CustomDelegate(QStyledItemDelegate):
             icon = index.data(Qt.DecorationRole).toPyObject();
             if icon != None:
                 x1,y1,x2,y2 = option.rect.getCoords()
-                painter.drawPixmap(x1+2,y1+6,50,50,icon)
+                painter.drawPixmap(x1+10,y1+6,50,50,icon)
                                                 
         # Draw tweet
         new_rect = painter.drawText(option.rect.adjusted(int(self.show_avatar)*70,0,0,0),  int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet); 
@@ -682,6 +692,91 @@ class CustomDelegate(QStyledItemDelegate):
 
         painter.restore()
 
+class WhiteCustomDelegate(QStyledItemDelegate):
+    '''Delegate to do custom draw of the items'''
+
+    def __init__(self, parent):
+        '''Initialization'''
+        QStyledItemDelegate.__init__(self, parent)
+        self.show_avatar = True
+        self.show_screenname = True
+        self.show_timestamp = True
+
+        self.tips_color = QColor('#7AB4F5')
+        self.bg_color = QColor('#FFFFFF')
+        self.bg_alternate_color = QColor('#dddddd')
+        self.text_color = QColor('#000000')
+                
+        self.fm = None
+        
+        self.normFont = None
+        self.miniFont = None
+
+    def sizeHint (self, option, index):
+        '''Custom size calculation of our items'''
+        size = QStyledItemDelegate.sizeHint(self, option, index)
+        tweet = index.data(Qt.DisplayRole).toString()
+        #One time is enought sizeHint need to be fast
+        if self.fm == None:
+            self.fm = QFontMetrics(option.font)
+        height = self.fm.boundingRect(0,0,option.rect.width()-75,800, int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet).height()
+        if height<37:
+            height=37        
+        return QSize(size.width(), height+25)
+        
+
+    def paint(self, painter, option, index):
+        '''Paint our tweet'''
+        self.fm = QFontMetrics(option.font)
+
+        model = index.model()
+        tweet = index.data(Qt.DisplayRole).toString()
+        
+        #Instantiate font only one time !
+        if self.normFont == None:
+            self.normFont = QFont(option.font)
+            self.miniFont = QFont(option.font)
+            self.miniFont.setPointSizeF(option.font.pointSizeF() * 0.80)            
+        
+        painter.save()
+        
+        # Draw alternate ?
+        if (index.row()%2)==0:
+            painter.fillRect(option.rect, self.bg_color)
+        else:
+            painter.fillRect(option.rect, self.bg_alternate_color)            
+
+        # highlight selected items
+        if option.state & QStyle.State_Selected: 
+            painter.fillRect(option.rect, option.palette.highlight());
+                    
+        # Draw icon
+        if self.show_avatar:
+            icon = index.data(Qt.DecorationRole).toPyObject();
+            if icon != None:
+                x1,y1,x2,y2 = option.rect.getCoords()
+                painter.drawPixmap(x1+10,y1+6,50,50,icon)
+                                                
+        # Draw tweet
+        painter.setPen(self.text_color)
+        new_rect = painter.drawText(option.rect.adjusted(int(self.show_avatar)*70,0,0,0),  int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet); 
+                
+        # Draw Timeline
+        if self.show_timestamp:
+            time = index.data(Qt.ToolTipRole).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.tips_color)
+            painter.drawText(option.rect.adjusted(70,0,-2,0),  int(Qt.AlignBottom) | int(Qt.AlignRight), time);
+
+        # Draw screenname
+        if self.show_screenname:
+            screenname = index.data(SCREENNAMEROLE).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.tips_color)
+            painter.drawText(option.rect.adjusted(70,0,-2,0),  int(Qt.AlignBottom) | int(Qt.AlignLeft), screenname);
+
+        painter.restore()
+        
 class KhweetsView(QListView):
     ''' Model View '''
     def __init__(self,parent=None):
@@ -689,8 +784,7 @@ class KhweetsView(QListView):
         #self.setIconSize(QSize(128, 128))
         #self.setStyleSheet('QListView { background-color: rgb(241, 245, 250); border: 0; }')
         self.setWordWrap(True)
-        self.custom_delegate = CustomDelegate(self)
-        self.setItemDelegate(self.custom_delegate)
+        self.refreshCustomDelegate()
         self.setEditTriggers(QAbstractItemView.SelectedClicked)
         self.setSpacing(2)
         self.setUniformItemSizes(False)
@@ -703,14 +797,26 @@ class KhweetsView(QListView):
 #        self.setAlternatingRowColors(True)  
 #        self.setAlternatingRowColors(True)
 
+    def refreshCustomDelegate(self):
+        theme = self.parent().settings.value('theme')
+        if theme == KhweeteurPref.WHITETHEME:
+            self.custom_delegate = WhiteCustomDelegate(self)
+        elif theme == KhweeteurPref.DEFAULTTHEME:
+            self.custom_delegate = DefaultCustomDelegate(self)
+        else:
+            self.custom_delegate = DefaultCustomDelegate(self)
+        self.setItemDelegate(self.custom_delegate)
+
 
 class KhweeteurAbout(QMainWindow):
+    '''About Window'''
     def __init__(self, parent=None):
         QMainWindow.__init__(self,parent)
         self.parent = parent
 
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        if isMAEMO:
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         self.setWindowTitle("Khweeteur About")
 
         aboutScrollArea = QScrollArea(self)
@@ -719,8 +825,12 @@ class KhweeteurAbout(QMainWindow):
         awidget.setMinimumSize(480,1000)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-        scroller = aboutScrollArea.property("kineticScroller").toPyObject()
-        scroller.setEnabled(True)
+        #Kinetic scroller is available on Maemo and should be on meego
+        try:
+            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+            scroller.setEnabled(True)
+        except:
+            pass
 
         aboutLayout = QVBoxLayout(awidget)
 
@@ -788,6 +898,10 @@ class KhweetAction(QDialog):
         self.retweet.setText(self.tr('&Retweet'))
         _layout.addWidget(self.retweet,0,1)
 
+        self.destroy_tweet = QPushButton('Destroy')
+        self.destroy_tweet.setText(self.tr('&Destroy'))
+        _layout.addWidget(self.destroy_tweet,1,1)
+
         self.openurl = QPushButton('Open URL')
         self.openurl.setText(self.tr('&Open URL'))
         _layout.addWidget(self.openurl,1,0)
@@ -801,12 +915,17 @@ class KhweetAction(QDialog):
         _layout.addWidget(self.unfollow,1,2)        
         
 class KhweeteurPref(QMainWindow):
+    DEFAULTTHEME = 'Default'
+    WHITETHEME = 'White'
+    THEMES = [DEFAULTTHEME,WHITETHEME,]
+
     def __init__(self, parent=None):
         QMainWindow.__init__(self,parent)
         self.parent = parent
 
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        if isMAEMO:
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         self.setWindowTitle("Khweeteur Prefs")
 
         self.settings = QSettings()
@@ -822,6 +941,9 @@ class KhweeteurPref(QMainWindow):
         self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
         self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
         self.useBitly_value.setCheckState(self.settings.value("useBitly").toInt()[0])
+        if self.settings.value("theme"):
+            self.settings.setValue("theme",'Default')
+        self.theme_value.setCurrentIndex(self.THEMES.index(self.settings.value("theme").toString()))
 
     def savePrefs(self):
         self.settings.setValue('refreshInterval',self.refresh_value.value())
@@ -831,6 +953,7 @@ class KhweeteurPref(QMainWindow):
         self.settings.setValue('displayAvatar',self.displayAvatar_value.checkState())
         self.settings.setValue('displayTimestamp',self.displayTimestamp_value.checkState())
         self.settings.setValue('useBitly',self.useBitly_value.checkState())
+        self.settings.setValue('theme',self.theme_value.currentText())
         self.emit(SIGNAL("save()"))
 
     def closeEvent(self,widget,*args):
@@ -874,7 +997,8 @@ class KhweeteurPref(QMainWindow):
                     pincode, ok = QInputDialog.getText(self, 'Twitter Authentification', 'Enter the pincode :')
     
                     if ok:
-                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+                        if isMAEMO:
+                            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
                         token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
                         token.set_verifier(str(pincode))
     
@@ -895,7 +1019,8 @@ class KhweeteurPref(QMainWindow):
                             self.settings.setValue('twitter_access_token',True)
                             self.twitter_value.setText('Clear Twitter Auth')
                             KhweeteurNotification().info('Khweeteur is now authorized to connect')
-                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                        if isMAEMO:
+                            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
                     
     def request_identica_access_or_clear(self):
 
@@ -936,7 +1061,8 @@ class KhweeteurPref(QMainWindow):
                     pincode, ok = QInputDialog.getText(self, 'Identi.ca Authentification', 'Enter the token :')
     
                     if ok:
-                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+                        if isMAEMO:
+                            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
                         token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
                         token.set_verifier(str(pincode))
     
@@ -957,7 +1083,8 @@ class KhweeteurPref(QMainWindow):
                             self.settings.setValue('identica_access_token',True)
                             self.identica_value.setText('Clear Identi.ca Auth')
                             KhweeteurNotification().info('Khweeteur is now authorized to connect')
-                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                        if isMAEMO:                        
+                            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
                         
     def setupGUI(self):
 #        self.aWidget = QWidget()
@@ -968,8 +1095,12 @@ class KhweeteurPref(QMainWindow):
         self.aWidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setWidget(self.aWidget)
-        scroller = self.scrollArea.property("kineticScroller").toPyObject()
-        scroller.setEnabled(True)
+        #Available on maemo but should be too on Meego
+        try:
+            scroller = self.scrollArea.property("kineticScroller").toPyObject()
+            scroller.setEnabled(True)
+        except:
+            pass
         self._main_layout = QGridLayout(self.aWidget)
 
         self._main_layout.addWidget(QLabel('Authorizations :'),0,0)
@@ -1016,6 +1147,12 @@ class KhweeteurPref(QMainWindow):
         self.useBitly_value = QCheckBox('Use Bit.ly')
         self._main_layout.addWidget(self.useBitly_value,8,1)
 
+        self._main_layout.addWidget(QLabel('Theme :'),9,0)
+        self.theme_value = QComboBox()
+        self._main_layout.addWidget(self.theme_value,9,1)
+        for theme in self.THEMES:
+            self.theme_value.addItem(theme)
+        
         self.aWidget.setLayout(self._main_layout)
 #        self.setCentralWidget(self.aWidget)
         self.setCentralWidget(self.scrollArea)
@@ -1031,9 +1168,10 @@ class KhweeteurWin(QMainWindow):
 
         #crappy trick to avoid search win to be garbage collected
         self.search_win = []
-            
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+
+        if isMAEMO:            
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
         if self.search_keyword != None:
             self.setWindowTitle("Khweeteur:"+unicode(self.search_keyword))      
@@ -1073,9 +1211,11 @@ class KhweeteurWin(QMainWindow):
         self.tweetsModel.refreshTimestamp()
 
     def timedUnserialize(self):
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+        if isMAEMO:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
         self.tweetsModel.unSerialize()
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+        if isMAEMO:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def setupMain(self):
 
@@ -1129,6 +1269,7 @@ class KhweeteurWin(QMainWindow):
         self.connect(self.tweetActionDialog.retweet,SIGNAL('clicked()'),self.retweet)
         self.connect(self.tweetActionDialog.follow,SIGNAL('clicked()'),self.follow)
         self.connect(self.tweetActionDialog.unfollow,SIGNAL('clicked()'),self.unfollow)
+        self.connect(self.tweetActionDialog.destroy_tweet,SIGNAL('clicked()'),self.destroy_tweet)
         self.tweetActionDialog.exec_()
         
     def countChar(self,text):
@@ -1176,7 +1317,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))
                             api.CreateFriendship(user_screenname)
                             self.notifications.info('You are now following %s on Twitter' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
                             print e.message
@@ -1192,7 +1333,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))    
                             api.CreateFriendship(user_screenname)
                             self.notifications.info('You are now following %s on Identi.ca' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
                             print e.message
@@ -1220,7 +1361,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))
                             api.DestroyFriendship(user_screenname)
                             self.notifications.info('You didn\'t follow %s anymore on Twitter' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
                             print e.message
@@ -1236,7 +1377,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))    
                             api.DestroyFriendship(user_screenname)
                             self.notifications.info('You didn\'t follow %s anymore on Identi.ca' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
                             print e.message
@@ -1261,7 +1402,7 @@ class KhweeteurWin(QMainWindow):
                         api.SetUserAgent('Khweeteur/%s' % (__version__))
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Twitter')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Retweet to twitter failed : '+(e.message))
                         print e.message
@@ -1277,7 +1418,7 @@ class KhweeteurWin(QMainWindow):
                         api.SetUserAgent('Khweeteur/%s' % (__version__))    
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Identi.ca')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Retweet to identi.ca failed : '+(e.message))
                         print e.message
@@ -1285,6 +1426,49 @@ class KhweeteurWin(QMainWindow):
                         self.notifications.warn('Retweet to identi.ca failed : '+str(e))
                         print e                 
 
+    def destroy_tweet(self):
+        self.tweetActionDialog.accept()
+        for index in self.tweetsView.selectedIndexes():
+            if ((QMessageBox.question(self,
+                       "Khweeteur",
+                       "Destroy this : %s ?" % self.tweetsModel._items[index.row()][3],
+                       QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
+                tweetid = self.tweetsModel._items[index.row()][1]
+                #print 'DEBUG Retweet:',tweetid
+                try:
+                    if self.settings.value("twitter_access_token_key").toString()!='':     
+                        api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
+                                          access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                          access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                        api.SetUserAgent('Khweeteur/%s' % (__version__))
+                        api.DestroyStatus(tweetid)
+                        self.tweetsModel.destroyStatus(index)
+                        self.notifications.info('Status destroyed on Twitter')
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    if type(e)==twitter.TwitterError:
+                        self.notifications.warn('Destroy status from twitter failed : '+(e.message))
+                        print e.message
+                    else:
+                        self.notifications.warn('Destroy status from twitter failed : '+str(e))
+                        print e                     
+                try:
+                    if self.settings.value("identica_access_token_key").toString()!='': 
+                        api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
+                                          password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
+                                          access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                          access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
+                        api.SetUserAgent('Khweeteur/%s' % (__version__))    
+                        api.DestroyStatus(tweetid)
+                        self.tweetsModel.destroyStatus(index)
+                        self.notifications.info('Status destroyed on Identi.ca')
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    if type(e)==twitter.TwitterError:
+                        self.notifications.warn('Destroy status from identi.ca failed : '+(e.message))
+                        print e.message
+                    else:
+                        self.notifications.warn('Destroy status from identi.ca failed : '+str(e))
+                        print e                 
+
     def tweetSent(self):
         self.tb_text.setText('')
         self.tb_text_replyid = 0
@@ -1319,7 +1503,8 @@ class KhweeteurWin(QMainWindow):
 
     def do_refresh_now(self):
         #print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+        if isMAEMO:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
         self.worker = KhweeteurWorker(self,search_keyword=self.search_keyword)
         self.connect(self.worker, SIGNAL("newStatuses(PyQt_PyObject)"), self.tweetsModel.addStatuses)
         self.connect(self.worker, SIGNAL("finished()"), self.refreshEnded)
@@ -1342,6 +1527,7 @@ class KhweeteurWin(QMainWindow):
             self.do_refresh_now()
  
     def restartTimer(self):
+        self.tweetsView.refreshCustomDelegate()
         self.tweetsView.custom_delegate.show_screenname = self.settings.value("displayUser").toBool()
         self.tweetsView.custom_delegate.show_timestamp = self.settings.value("displayTimestamp").toBool()
         self.tweetsView.custom_delegate.show_avatar = self.settings.value("displayAvatar").toBool()
